@@ -9,4 +9,7 @@ def args_parser():
     parser.add_argument('--debug', default=False, action='store_true',
                         help='debug process of assembler')
 
+    parser.add_argument('--dry-run', default=False, action='store_true',
+                        help='Dry run assemble process. Useful with --debug')
+
     return parser.parse_args()
